@@ -234,7 +234,7 @@ sub daemon_ok {
   $invocation .= " 2>$localname.test.status ";
   if (!$generate) {
     pathname_chdir($workdir);
-    is(system($invocation), 0, "latexmlc invocation for test $localname");
+    is(system($invocation), 0, "latexmlc invocation for test $localname: $!");
     pathname_chdir($current_dir);
     # Compare the just generated $base.test.xml to the previous $base.xml
     if (my $teststrings = process_xmlfile("$workdir/$localname.test.xml", $base)) {
